function [s,vel,acc] = sinoid_pl2(se,tb,tv,te,vm,am,dt)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
%sinoid_pl2.m
%SINOID Berechnung des Sinoidprofils
% 
% [s,vel,acc] = sinoid_pl2(se,tb,tv,te,vm,am,dt)
%
%
% INPUT:	
%	se [se(1)	Strecke
%	    se(2)
%	     ...]
%	     
%	tb [tb(1)	Beschleunigungszeit
%	    tb(2)
%	     ...]
%	     
%	tv [tv(1)	Bremszeit
%	    tv(2)
%	     ...]
%	     
%	te [te(1)	Gesamtzeit der Bahn
%	    te(2)
%	     ...]
%	     	    	    		
%	vm [vm(1)	maximale Geschwindigkeit
%	    vm(2)
%	     ...]
%	    
%	am [am(1)	maximale Beschleunigung
%	    am(2)
%	     ...]
%	    	
%	dt		Interpolationszeit
%	
% OUTPUT:
%
%	s			Matrix der Streckennderungen mit Rampenprofil 	
% 	vel		Matrix der Geschwindigkeitsnderungen mit Rampenprofil   (nur ds/dt, kein Vorzeichen) 
% 	acc		Matrix der Beschleunigungsnderungen mit Rampenprofil	   (nur ds/dt, kein Vorzeichen)
% 		
% globale Variablen:
%			keine
%		
% aufgerufene Funktionen:
%			keine
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Initialisierung
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

rows  = size(se,1);			% extrahieren der Spaltenanzahl
temax = max(te);			% maximale Bahndauer
tast  = round(temax/dt);  		% Anzahl der Spalten der Gelenkwinkelmatrix und des Zeitvektors
st    = zeros(rows,1);
s     = zeros(rows, tast);    		% Vordimensionierung der Gelenkwinkelmatrix
at   = zeros(rows,1);
acc  = zeros(rows,tast);		% Vordimensionierung der Beschleunigungsmatrix
vt   = zeros(rows,1);			
vel  = zeros(rows,tast);		% Vordimensionierung der Geschwindigkeitsmatrix
zero = zeros(rows,1);
	
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Berechnung der Sollwerte (Winkel oder Schublnge)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

for h=1:1:tast,

  t = h *dt;
  
  i= find(  0 <=t  &  t <= tb); 	
  st(i) = am(i).*((.25*(t).^2)+((tb(i)).^2./(8*(pi).^2)).*(cos((2*pi./tb(i))*t)-1));
  
  i= find( tb < t  &  t <= tv); 	
  st(i) = vm(i).*(t-.5*tb(i));
  
  i= find( tv < t  &  t <= te); 	
  st(i) = (.5*am(i)).*((te(i)*t)-(.5*(t).^2)+(te(i).*tb(i))...
  -(.5*(te(i)).^2)-((tb(i)).^2)+((tb(i)).^2/(4*(pi).^2)).*(1-cos((2*pi./tb(i)).*(t-tv(i)))));
  
  i= find( te < t 	);	
  st(i) = se(i);
	
  s(:,h) = st;
  
end;


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Berechnung der Beschleunigungsmatrix acc
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

for h =1:1: tast,

  t= h * dt;
	
  i = find(0 <=  t & t <=tb); 	
  at(i) = +am(i).*(sin((pi./tb(i))*t).^2);
  
  i = find(tb <= t & t <=tv);	
  at(i) = zero(i);
  
  i = find(tv <= t & t <= te);	
  at(i) = -am(i).*(sin((pi./tb(i)).*(te(i)-t)).^2);
  
  i = find(te < t);		
  at(i) = zero(i);

  acc(:,h)=at;
  
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Berechnung der Geschwindigkeitsmatrix vel
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

for h =1:1: tast,
  t= h * dt;
	
  i = find(0 <=  t & t <=tb);	
  vt(i) = (.5*am(i)).*(t - (tb(i)/(2*pi)).*(sin((2*pi./tb(i))*t)));
   	
  i = find(tb <= t & t <=tv);	
  vt(i) = .5*am(i).*tb(i);
  
  i = find(tv <= t & t <= te);	
  vt(i) = .5*am(i).*(te(i)-t + (tb(i)/(2*pi)).*sin((((2*pi)./tb(i))).*(t-tv(i))));
  
  i = find(te < t);		
  vt(i) =  zero(i);
  
  vel(:,h)=vt;
end
